<?php
//
// ZoneMinder web Argentinian Spanish language file, $Date: 2008-01-08 12:33:11 +0000 (Tue, 08 Jan 2008) $, $Revision: 2281 $
// Copyright (C) 2003, 2004, 2005, 2006  Philip Coombes
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//

// ZoneMinder Spanish 'Argentina' Translation by Fernando Diaz.

// Simple String Replacements
$zmSlang24BitColour          = 'Color 24 bits';
$zmSlang8BitGrey             = 'Grises 8 bits';
$zmSlangAction               = 'Action';
$zmSlangActual               = 'Actual';
$zmSlangAddNewControl        = 'Add New Control';
$zmSlangAddNewMonitor        = 'Agregar Nuevo Monitor';
$zmSlangAddNewUser           = 'Agregar Nuevo Usuario';
$zmSlangAddNewZone           = 'Agregar Nueva Zona';
$zmSlangAlarm                = 'Alarma';
$zmSlangAlarmBrFrames        = 'Alarma<br/>Cuadros';
$zmSlangAlarmFrameCount      = 'Alarm Frame Count';
$zmSlangAlarmFrame           = 'Cuadro Alarma';
$zmSlangAlarmLimits          = 'Alarm Limits';
$zmSlangAlarmMaximumFPS      = 'Alarm Maximum FPS';
$zmSlangAlarmPx              = 'Alarm Px';
$zmSlangAlarmRGBUnset        = 'You must set an alarm RGB colour';
$zmSlangAlert                = 'Alerta';
$zmSlangAll                  = 'Todo';
$zmSlangApply                = 'Aplicar';
$zmSlangApplyingStateChange  = 'Aplicar Cambio Estado';
$zmSlangArchArchived         = 'Solo Archivados';
$zmSlangArchive              = 'Archivar';
$zmSlangArchived             = 'Archived';
$zmSlangArchUnarchived       = 'Solo Sin Archivar';
$zmSlangArea                 = 'Area';
$zmSlangAreaUnits            = 'Area (px/%)';
$zmSlangAttrAlarmFrames      = 'Alarm Frames';
$zmSlangAttrArchiveStatus    = 'Estado Archivo';
$zmSlangAttrAvgScore         = 'Puntaje Prom.';
$zmSlangAttrCause            = 'Cause';
$zmSlangAttrDate             = 'Fecha';
$zmSlangAttrDateTime         = 'Fecha/Hora';
$zmSlangAttrDiskBlocks       = 'Disk Blocks';
$zmSlangAttrDiskPercent      = 'Disk Percent';
$zmSlangAttrDuration         = 'Duracin';
$zmSlangAttrFrames           = 'Cuadros';
$zmSlangAttrId               = 'Id';
$zmSlangAttrMaxScore         = 'Puntaje Mximo';
$zmSlangAttrMonitorId        = 'Monitor Id';
$zmSlangAttrMonitorName      = 'Nombre Monitor';
$zmSlangAttrMontage          = 'Cmara Mltiple';
$zmSlangAttrName             = 'Name';
$zmSlangAttrNotes            = 'Notes';
$zmSlangAttrSystemLoad       = 'System Load';
$zmSlangAttrTime             = 'Hora';
$zmSlangAttrTotalScore       = 'Puntaje Total';
$zmSlangAttrWeekday          = 'Da Semana';
$zmSlangAuto                 = 'Auto';
$zmSlangAutoStopTimeout      = 'Auto Stop Timeout';
$zmSlangAvgBrScore           = 'Punt.<br/>Promedio';
$zmSlangBackground           = 'Background';
$zmSlangBackgroundFilter     = 'Run filter in background';
$zmSlangBadAlarmFrameCount   = 'Alarm frame count must be an integer of one or more';
$zmSlangBadAlarmMaxFPS       = 'Alarm Maximum FPS must be a positive integer or floating point value';
$zmSlangBadChannel           = 'Channel must be set to an integer of zero or more';
$zmSlangBadDevice            = 'Device must be set to a valid value';
$zmSlangBadFormat            = 'Format must be set to an integer of zero or more';
$zmSlangBadFPSReportInterval = 'FPS report interval buffer count must be an integer of 100 or more';
$zmSlangBadFrameSkip         = 'Frame skip count must be an integer of zero or more';
$zmSlangBadHeight            = 'Height must be set to a valid value';
$zmSlangBadHost              = 'Host must be set to a valid ip address or hostname, do not include http://';
$zmSlangBadImageBufferCount  = 'Image buffer size must be an integer of 10 or more';
$zmSlangBadLabelX            = 'Label X co-ordinate must be set to an integer of zero or more';
$zmSlangBadLabelY            = 'Label Y co-ordinate must be set to an integer of zero or more';
$zmSlangBadMaxFPS            = 'Maximum FPS must be a positive integer or floating point value';
$zmSlangBadNameChars         = 'Los nombres pueden contener solamente caracteres alfanumricos ms el guin y la raya';
$zmSlangBadPath              = 'Path must be set to a valid value';
$zmSlangBadPort              = 'Port must be set to a valid number';
$zmSlangBadPostEventCount    = 'Post event image count must be an integer of zero or more';
$zmSlangBadPreEventCount     = 'Pre event image count must be at least zero, and less than image buffer size';
$zmSlangBadRefBlendPerc      = 'Reference blend percentage must be a positive integer';
$zmSlangBadSectionLength     = 'Section length must be an integer of 30 or more';
$zmSlangBadSignalCheckColour = 'Signal check colour must be a valid RGB colour string';
$zmSlangBadStreamReplayBuffer= 'Stream replay buffer must be an integer of zero or more';
$zmSlangBadWarmupCount       = 'Warmup frames must be an integer of zero or more';
$zmSlangBadWebColour         = 'Web colour must be a valid web colour string';
$zmSlangBadWidth             = 'Width must be set to a valid value';
$zmSlangBandwidth            = 'Velocidad';
$zmSlangBlobPx               = 'Blob Px';
$zmSlangBlobs                = 'Blobs';
$zmSlangBlobSizes            = 'Blob Sizes';
$zmSlangBrightness           = 'Brillo';
$zmSlangBuffers              = 'Buffers';
$zmSlangCanAutoFocus         = 'Can Auto Focus';
$zmSlangCanAutoGain          = 'Can Auto Gain';
$zmSlangCanAutoIris          = 'Can Auto Iris';
$zmSlangCanAutoWhite         = 'Can Auto White Bal.';
$zmSlangCanAutoZoom          = 'Can Auto Zoom';
$zmSlangCancel               = 'Cancelar';
$zmSlangCancelForcedAlarm    = 'Cancelar Alarma Forzada';
$zmSlangCanFocusAbs          = 'Can Focus Absolute';
$zmSlangCanFocus             = 'Can Focus';
$zmSlangCanFocusCon          = 'Can Focus Continuous';
$zmSlangCanFocusRel          = 'Can Focus Relative';
$zmSlangCanGainAbs           = 'Can Gain Absolute';
$zmSlangCanGain              = 'Can Gain ';
$zmSlangCanGainCon           = 'Can Gain Continuous';
$zmSlangCanGainRel           = 'Can Gain Relative';
$zmSlangCanIrisAbs           = 'Can Iris Absolute';
$zmSlangCanIris              = 'Can Iris';
$zmSlangCanIrisCon           = 'Can Iris Continuous';
$zmSlangCanIrisRel           = 'Can Iris Relative';
$zmSlangCanMoveAbs           = 'Can Move Absolute';
$zmSlangCanMove              = 'Can Move';
$zmSlangCanMoveCon           = 'Can Move Continuous';
$zmSlangCanMoveDiag          = 'Can Move Diagonally';
$zmSlangCanMoveMap           = 'Can Move Mapped';
$zmSlangCanMoveRel           = 'Can Move Relative';
$zmSlangCanPan               = 'Can Pan' ;
$zmSlangCanReset             = 'Can Reset';
$zmSlangCanSetPresets        = 'Can Set Presets';
$zmSlangCanSleep             = 'Can Sleep';
$zmSlangCanTilt              = 'Can Tilt';
$zmSlangCanWake              = 'Can Wake';
$zmSlangCanWhiteAbs          = 'Can White Bal. Absolute';
$zmSlangCanWhiteBal          = 'Can White Bal.';
$zmSlangCanWhite             = 'Can White Balance';
$zmSlangCanWhiteCon          = 'Can White Bal. Continuous';
$zmSlangCanWhiteRel          = 'Can White Bal. Relative';
$zmSlangCanZoomAbs           = 'Can Zoom Absolute';
$zmSlangCanZoom              = 'Can Zoom';
$zmSlangCanZoomCon           = 'Can Zoom Continuous';
$zmSlangCanZoomRel           = 'Can Zoom Relative';
$zmSlangCaptureHeight        = 'Captura Alto';
$zmSlangCapturePalette       = 'Captura Paleta';
$zmSlangCaptureWidth         = 'Captura Ancho';
$zmSlangCause                = 'Cause';
$zmSlangCheckMethod          = 'Alarm Check Method';
$zmSlangChooseFilter         = 'Elegir Filtro';
$zmSlangChoosePreset         = 'Choose Preset';
$zmSlangClose                = 'Cerrar';
$zmSlangColour               = 'Color';
$zmSlangCommand              = 'Command';
$zmSlangConfig		     = 'Config.';
$zmSlangConfiguredFor        = 'Configurado Para';
$zmSlangConfirmDeleteEvents  = 'Are you sure you wish to delete the selected events?';
$zmSlangConfirmPassword      = 'Confirmar Contrasea';
$zmSlangConjAnd              = 'y';
$zmSlangConjOr               = 'o';
$zmSlangConsole              = 'Consola';
$zmSlangConsole              = 'Console'; 
$zmSlangContactAdmin         = 'Contacte el Administrador para detalles.';
$zmSlangContinue             = 'Continue';
$zmSlangContrast             = 'Contraste';
$zmSlangControlAddress       = 'Control Address';
$zmSlangControlCap           = 'Control Capability';
$zmSlangControlCaps          = 'Control Capabilities';
$zmSlangControl              = 'Control';
$zmSlangControlDevice        = 'Control Device';
$zmSlangControllable         = 'Controllable';
$zmSlangControlType          = 'Control Type';
$zmSlangCycle                = 'Cycle';
$zmSlangCycleWatch           = 'Cycle Watch';
$zmSlangDay                  = 'Da';
$zmSlangDebug                = 'Debug';
$zmSlangDefaultRate          = 'Default Rate';
$zmSlangDefaultScale         = 'Default Scale';
$zmSlangDefaultView          = 'Default View';
$zmSlangDeleteAndNext        = 'Borrar &amp; Prximo';
$zmSlangDeleteAndPrev        = 'Borrar &amp; Anterior';
$zmSlangDelete               = 'Borrar';
$zmSlangDeleteSavedFilter    = 'Borrar Filtro Guardado';
$zmSlangDescription          = 'Descripcin';
$zmSlangDeviceChannel        = 'Canal';
$zmSlangDeviceFormat         = 'Seal';
$zmSlangDeviceNumber         = 'Fuente';
$zmSlangDevicePath           = 'Device Path';
$zmSlangDevices              = 'Devices';
$zmSlangDimensions           = 'Dimensiones';
$zmSlangDisableAlarms        = 'Disable Alarms';
$zmSlangDisk                 = 'Disco';
$zmSlangDonateAlready        = 'No, I\'ve already donated';
$zmSlangDonateEnticement     = 'You\'ve been running ZoneMinder for a while now and hopefully are finding it a useful addition to your home or workplace security. Although ZoneMinder is, and will remain, free and open source, it costs money to develop and support. If you would like to help support future development and new features then please consider donating. Donating is, of course, optional but very much appreciated and you can donate as much or as little as you like.<br><br>If you would like to donate please select the option below or go to http://www.zoneminder.com/donate.html in your browser.<br><br>Thank you for using ZoneMinder and don\'t forget to visit the forums on ZoneMinder.com for support or suggestions about how to make your ZoneMinder experience even better.';
$zmSlangDonate               = 'Please Donate';
$zmSlangDonateRemindDay      = 'Not yet, remind again in 1 day';
$zmSlangDonateRemindHour     = 'Not yet, remind again in 1 hour';
$zmSlangDonateRemindMonth    = 'Not yet, remind again in 1 month';
$zmSlangDonateRemindNever    = 'No, I don\'t want to donate, never remind';
$zmSlangDonateRemindWeek     = 'Not yet, remind again in 1 week';
$zmSlangDonateYes            = 'Yes, I\'d like to donate now';
$zmSlangDownload             = 'Download';
$zmSlangDuration             = 'Duracin';
$zmSlangEdit                 = 'Editar';
$zmSlangEmail                = 'Email';
$zmSlangEnableAlarms         = 'Enable Alarms';
$zmSlangEnabled              = 'Habilitado';
$zmSlangEnterNewFilterName   = 'Ingresar Nuevo Nombre De Filtro';
$zmSlangErrorBrackets        = 'Error, Revisar si tiene la misma cantidad de parntesis de apertura';
$zmSlangError                = 'Error';
$zmSlangErrorValidValue      = 'Error, Revisar si los trminos tienen nombres validos';
$zmSlangEtc                  = 'etc';
$zmSlangEvent                = 'Evento';
$zmSlangEventFilter          = 'Filtro de Evento';
$zmSlangEventId              = 'Event Id';
$zmSlangEventName            = 'Event Name';
$zmSlangEventPrefix          = 'Event Prefix';
$zmSlangEvents               = 'Eventos';
$zmSlangExclude              = 'Excluir';
$zmSlangExecute              = 'Execute';
$zmSlangExportDetails        = 'Export Event Details';
$zmSlangExport               = 'Export';
$zmSlangExportFailed         = 'Export Failed';
$zmSlangExportFormat         = 'Export File Format';
$zmSlangExportFormatTar      = 'Tar';
$zmSlangExportFormatZip      = 'Zip';
$zmSlangExportFrames         = 'Export Frame Details';
$zmSlangExportImageFiles     = 'Export Image Files';
$zmSlangExporting            = 'Exporting';
$zmSlangExportMiscFiles      = 'Export Other Files (if present)';
$zmSlangExportOptions        = 'Export Options';
$zmSlangExportVideoFiles     = 'Export Video Files (if present)';
$zmSlangFar                  = 'Far';
$zmSlangFastForward          = 'Fast Forward';
$zmSlangFeed                 = 'Vista';
$zmSlangFileColours          = 'File Colours';
$zmSlangFile                 = 'File';
$zmSlangFilePath             = 'File Path';
$zmSlangFilterArchiveEvents  = 'Archivar todos los eventos';
$zmSlangFilterDeleteEvents   = 'Borrar todos los eventos';
$zmSlangFilterEmailEvents    = 'Mandar un mail de todos los eventos';
$zmSlangFilterExecuteEvents  = 'Ejecutar un comando en las coincidencias';
$zmSlangFilterMessageEvents  = 'Mandar un mensaje de los eventos';
$zmSlangFilterPx             = 'Filtro Px';
$zmSlangFilters              = 'Filters';
$zmSlangFilterUnset          = 'You must specify a filter width and height';
$zmSlangFilterUploadEvents   = 'Subir los eventos que coincidan';
$zmSlangFilterVideoEvents    = 'Create video for all matches';
$zmSlangFirst                = 'Primero';
$zmSlangFlippedHori          = 'Flipped Horizontally';
$zmSlangFlippedVert          = 'Flipped Vertically';
$zmSlangFocus                = 'Focus';
$zmSlangForceAlarm           = 'Forzar Alarma';
$zmSlangFormat               = 'Format';
$zmSlangFPS                  = 'fps';
$zmSlangFPSReportInterval    = 'Intervalo de Reporte FPS';
$zmSlangFrame                = 'Cuadro';
$zmSlangFrameId              = 'Id Cuadro';
$zmSlangFrameRate            = 'Velocidad del video';
$zmSlangFrames               = 'Cuadros';
$zmSlangFrameSkip            = 'Saltear Cuadro';
$zmSlangFTP                  = 'FTP';
$zmSlangFunc                 = 'Func';
$zmSlangFunction             = 'Funcin';
$zmSlangGain                 = 'Gain';
$zmSlangGeneral              = 'General';
$zmSlangGenerateVideo        = 'Crear Video';
$zmSlangGeneratingVideo      = 'Creando Video';
$zmSlangGoToZoneMinder       = 'Ir a Zoneminder.com';
$zmSlangGrey                 = 'Gris';
$zmSlangGroup                = 'Group';
$zmSlangGroups               = 'Groups';
$zmSlangHasFocusSpeed        = 'Has Focus Speed';
$zmSlangHasGainSpeed         = 'Has Gain Speed';
$zmSlangHasHomePreset        = 'Has Home Preset';
$zmSlangHasIrisSpeed         = 'Has Iris Speed';
$zmSlangHasPanSpeed          = 'Has Pan Speed';
$zmSlangHasPresets           = 'Has Presets';
$zmSlangHasTiltSpeed         = 'Has Tilt Speed';
$zmSlangHasTurboPan          = 'Has Turbo Pan';
$zmSlangHasTurboTilt         = 'Has Turbo Tilt';
$zmSlangHasWhiteSpeed        = 'Has White Bal. Speed';
$zmSlangHasZoomSpeed         = 'Has Zoom Speed';
$zmSlangHigh                 = 'Alta';
$zmSlangHighBW               = 'Alta&nbsp;B/W';
$zmSlangHome                 = 'Home';
$zmSlangHour                 = 'Hora';
$zmSlangHue                  = 'Saturacin';
$zmSlangId                   = 'Id';
$zmSlangIdle                 = 'Pasivo';
$zmSlangIgnore               = 'Ignorar';
$zmSlangImageBufferSize      = 'Tamao del Buffer de Imagen';
$zmSlangImage                = 'Imagen';
$zmSlangImages               = 'Images';
$zmSlangInclude              = 'Incluir';
$zmSlangIn                   = 'In';
$zmSlangInverted             = 'Invertido';
$zmSlangIris                 = 'Iris';
$zmSlangIsequalto            = 'Es igual a';
$zmSlangIsEqualTo            = 'is equal to'; 
$zmSlangKeyString            = 'Key String';
$zmSlangLabel                = 'Label';
$zmSlangLanguage             = 'Lenguaje';
$zmSlangLast                 = 'Ultimo';
$zmSlangLimitResultsPost     = 'Resultados;'; // This is used at the end of the phrase 'Limit to first N results only'
$zmSlangLimitResultsPre      = 'Solo los primeros'; // This is used at the beginning of the phrase 'Limit to first N results only'
$zmSlangLinkedMonitors       = 'Linked Monitors';
$zmSlangList                 = 'List';
$zmSlangLoad                 = 'Carga';
$zmSlangLocal                = 'Local';
$zmSlangLoggedInAs           = 'Registrado Como';
$zmSlangLoggingIn            = 'Ingresando';
$zmSlangLogin                = 'Ingresar';
$zmSlangLogout               = 'Salir';
$zmSlangLow                  = 'Baja';
$zmSlangLowBW                = 'Baja&nbsp;B/W';
$zmSlangMain                 = 'Main';
$zmSlangMan                  = 'Man';
$zmSlangManual               = 'Manual';
$zmSlangMark                 = 'Marca';
$zmSlangMaxBandwidth         = 'Max Bandwidth';
$zmSlangMaxBrScore           = 'Puntaje<br/>Max.';
$zmSlangMaxFocusRange        = 'Max Focus Range';
$zmSlangMaxFocusSpeed        = 'Max Focus Speed';
$zmSlangMaxFocusStep         = 'Max Focus Step';
$zmSlangMaxGainRange         = 'Max Gain Range';
$zmSlangMaxGainSpeed         = 'Max Gain Speed';
$zmSlangMaxGainStep          = 'Max Gain Step';
$zmSlangMaximumFPS           = 'Maximos FPS';
$zmSlangMaxIrisRange         = 'Max Iris Range';
$zmSlangMaxIrisSpeed         = 'Max Iris Speed';
$zmSlangMaxIrisStep          = 'Max Iris Step';
$zmSlangMax                  = 'Max';
$zmSlangMaxPanRange          = 'Max Pan Range';
$zmSlangMaxPanSpeed          = 'Max Pan Speed';
$zmSlangMaxPanStep           = 'Max Pan Step';
$zmSlangMaxTiltRange         = 'Max Tilt Range';
$zmSlangMaxTiltSpeed         = 'Max Tilt Speed';
$zmSlangMaxTiltStep          = 'Max Tilt Step';
$zmSlangMaxWhiteRange        = 'Max White Bal. Range';
$zmSlangMaxWhiteSpeed        = 'Max White Bal. Speed';
$zmSlangMaxWhiteStep         = 'Max White Bal. Step';
$zmSlangMaxZoomRange         = 'Max Zoom Range';
$zmSlangMaxZoomSpeed         = 'Max Zoom Speed';
$zmSlangMaxZoomStep          = 'Max Zoom Step';
$zmSlangMediumBW             = 'Media&nbsp;B/W';
$zmSlangMedium               = 'Media';
$zmSlangMinAlarmAreaLtMax    = 'Minimum alarm area should be less than maximum';
$zmSlangMinAlarmAreaUnset    = 'You must specify the minimum alarm pixel count';
$zmSlangMinBlobAreaLtMax     = 'Minimum blob area should be less than maximum';
$zmSlangMinBlobAreaUnset     = 'You must specify the minimum blob pixel count';
$zmSlangMinBlobLtMinFilter   = 'Minimum blob area should be less than or equal to minimum filter area';
$zmSlangMinBlobsLtMax        = 'Minimum blobs should be less than maximum';
$zmSlangMinBlobsUnset        = 'You must specify the minimum blob count';
$zmSlangMinFilterAreaLtMax   = 'Minimum filter area should be less than maximum';
$zmSlangMinFilterAreaUnset   = 'You must specify the minimum filter pixel count';
$zmSlangMinFilterLtMinAlarm  = 'Minimum filter area should be less than or equal to minimum alarm area';
$zmSlangMinFocusRange        = 'Min Focus Range';
$zmSlangMinFocusSpeed        = 'Min Focus Speed';
$zmSlangMinFocusStep         = 'Min Focus Step';
$zmSlangMinGainRange         = 'Min Gain Range';
$zmSlangMinGainSpeed         = 'Min Gain Speed';
$zmSlangMinGainStep          = 'Min Gain Step';
$zmSlangMinIrisRange         = 'Min Iris Range';
$zmSlangMinIrisSpeed         = 'Min Iris Speed';
$zmSlangMinIrisStep          = 'Min Iris Step';
$zmSlangMinPanRange          = 'Min Pan Range';
$zmSlangMinPanSpeed          = 'Min Pan Speed';
$zmSlangMinPanStep           = 'Min Pan Step';
$zmSlangMinPixelThresLtMax   = 'Minimum pixel threshold should be less than maximum';
$zmSlangMinPixelThresUnset   = 'You must specify a minimum pixel threshold';
$zmSlangMinTiltRange         = 'Min Tilt Range';
$zmSlangMinTiltSpeed         = 'Min Tilt Speed';
$zmSlangMinTiltStep          = 'Min Tilt Step';
$zmSlangMinWhiteRange        = 'Min White Bal. Range';
$zmSlangMinWhiteSpeed        = 'Min White Bal. Speed';
$zmSlangMinWhiteStep         = 'Min White Bal. Step';
$zmSlangMinZoomRange         = 'Min Zoom Range';
$zmSlangMinZoomSpeed         = 'Min Zoom Speed';
$zmSlangMinZoomStep          = 'Min Zoom Step';
$zmSlangMisc                 = 'Otros';
$zmSlangMonitorIds           = 'Ids&nbsp;Monitor';
$zmSlangMonitor              = 'Monitor';
$zmSlangMonitorPresetIntro   = 'Select an appropriate preset from the list below.<br><br>Please note that this may overwrite any values you already have configured for this monitor.<br><br>';
$zmSlangMonitorPreset        = 'Monitor Preset';
$zmSlangMonitors             = 'Monitores';
$zmSlangMontage              = 'Cmara Mltiple';
$zmSlangMonth                = 'Mes';
$zmSlangMove                 = 'Move';
$zmSlangMustBeGe             = 'Debe ser mayor o igual que';
$zmSlangMustBeLe             = 'Debe ser menor o igual que';
$zmSlangMustConfirmPassword  = 'Debe confirmar la contrasea';
$zmSlangMustSupplyPassword   = 'Debe ingresar una contrasea';
$zmSlangName                 = 'Nombre';
$zmSlangNear                 = 'Near';
$zmSlangNetwork              = 'Red';
$zmSlangNewGroup             = 'New Group';
$zmSlangNewLabel             = 'New Label';
$zmSlangNew                  = 'Nuevo';
$zmSlangNewPassword          = 'Nueva Contrasea';
$zmSlangNewState             = 'Nuevo Estado';
$zmSlangNewUser              = 'Nuevo Usuario';
$zmSlangNext                 = 'Siguiente';
$zmSlangNoFramesRecorded     = 'No hay movimientos grabados para este evento';
$zmSlangNoGroup              = 'No Group';
$zmSlangNoneAvailable        = 'Ninguno Disponible';
$zmSlangNone                 = 'Ninguno';
$zmSlangNo                   = 'No';
$zmSlangNormal               = 'Normal';
$zmSlangNoSavedFilters       = 'FiltrosNoGuardados';
$zmSlangNoStatisticsRecorded = 'No hay estadisticas guardadas para este evento/marco';
$zmSlangNotes                = 'Notes';
$zmSlangNumPresets           = 'Num Presets';
$zmSlangOff                  = 'Off';
$zmSlangOn                   = 'On';
$zmSlangOpen                 = 'Open';
$zmSlangOpEq                 = 'igual que';
$zmSlangOpGtEq               = 'mayor o igual que';
$zmSlangOpGt                 = 'mayor que';
$zmSlangOpIn                 = 'En sistema';
$zmSlangOpLtEq               = 'menor o igual que';
$zmSlangOpLt                 = 'menor que';
$zmSlangOpMatches            = 'Coincide';
$zmSlangOpNe                 = 'distinto que';
$zmSlangOpNotIn              = 'No en sistema';
$zmSlangOpNotMatches         = 'No coincide';
$zmSlangOptionHelp           = 'Ayuda';
$zmSlangOptionRestartWarning = 'Estos cambios no se guardaran completamente\nmientras el sistema se ejecute. Cuando termine\nde realizar los cambios asegurese de\nreiniciar Zoneminder.';
$zmSlangOptions              = 'Opciones';
$zmSlangOrder                = 'Order';
$zmSlangOrEnterNewName       = 'o agregue  nombre';
$zmSlangOrientation          = 'Orientacin';
$zmSlangOut                  = 'Out';
$zmSlangOverwriteExisting    = 'Sobreescribir Exitente';
$zmSlangPaged                = 'Paged';
$zmSlangPanLeft              = 'Pan Left';
$zmSlangPan                  = 'Pan';
$zmSlangPanRight             = 'Pan Right';
$zmSlangPanTilt              = 'Pan/Tilt';
$zmSlangParameter            = 'Parametro';
$zmSlangPassword             = 'Contrasea';
$zmSlangPasswordsDifferent   = 'Las contraseas nueva y de confirmacion son diferentes';
$zmSlangPaths                = 'Enlaces';
$zmSlangPause                = 'Pause';
$zmSlangPhoneBW              = 'Tel.&nbsp;B/N';
$zmSlangPhone                = 'Phone';
$zmSlangPixels               = 'pixels';
$zmSlangPlayAll              = 'Play All';
$zmSlangPlay                 = 'Play';
$zmSlangPleaseWait           = 'Espere por favor';
$zmSlangPoint                = 'Point';
$zmSlangPostEventImageBuffer = 'Buffer Imagenes despues evento';
$zmSlangPreEventImageBuffer  = 'Buffer Imagenes antes evento';
$zmSlangPreserveAspect       = 'Preserve Aspect Ratio';
$zmSlangPreset               = 'Preset';
$zmSlangPresets              = 'Presets';
$zmSlangPrev                 = 'Prev';
$zmSlangProtocol             = 'Protocol';
$zmSlangRate                 = 'Ritmo';
$zmSlangReal                 = 'Real';
$zmSlangRecord               = 'Registro';
$zmSlangRefImageBlendPct     = 'Reference Image Blend %ge';
$zmSlangRefresh              = 'Actualizar';
$zmSlangRemoteHostName       = 'Nombre Servidor Remoto';
$zmSlangRemoteHostPath       = 'Enlace Servidor Remoto';
$zmSlangRemoteHostPort       = 'Puerto Servidor Remoto';
$zmSlangRemoteImageColours   = 'Remote Image Colours';
$zmSlangRemote               = 'Remote';
$zmSlangRename               = 'Renombrar';
$zmSlangReplayAll            = 'All Events';
$zmSlangReplayGapless        = 'Gapless Events';
$zmSlangReplay               = 'Replay';
$zmSlangReplaySingle         = 'Single Event';
$zmSlangResetEventCounts     = 'Borrar Contador Eventos';
$zmSlangReset                = 'Reset';
$zmSlangRestarting           = 'Reiniciando';
$zmSlangRestart              = 'Reiniciar';
$zmSlangRestrictedCameraIds  = 'Id. Camara restringida';
$zmSlangRestrictedMonitors   = 'Restricted Monitors';
$zmSlangReturnDelay          = 'Return Delay';
$zmSlangReturnLocation       = 'Return Location';
$zmSlangRewind               = 'Rewind';
$zmSlangRotateLeft           = 'Rotar a la derecha';
$zmSlangRotateRight          = 'Rotar a la izquierda';
$zmSlangRunMode              = 'Metodo Ejecucion';
$zmSlangRunning              = 'Ejecutando';
$zmSlangRunState             = 'Estado de Ejecucin';
$zmSlangSaveAs               = 'Guardar Como';
$zmSlangSaveFilter           = 'Guardar Filtro';
$zmSlangSave                 = 'Guardar';
$zmSlangScale                = 'Escala';
$zmSlangScore                = 'Res.';
$zmSlangSecs                 = 'Seg';
$zmSlangSectionlength        = 'Longitud Seccin';
$zmSlangSelectMonitors       = 'Select Monitors';
$zmSlangSelect               = 'Select';
$zmSlangSelfIntersecting     = 'Polygon edges must not intersect';
$zmSlangServerLoad           = 'Carga Servidor';
$zmSlangSetLearnPrefs        = 'Set Learn Prefs'; // This can be ignored for now
$zmSlangSetNewBandwidth      = 'Nuevo Ancho de Banda';
$zmSlangSetPreset            = 'Set Preset';
$zmSlangSet                  = 'Set';
$zmSlangSettings             = 'Configuracion';
$zmSlangShowFilterWindow     = 'Abrir Filtro';
$zmSlangShowTimeline         = 'Show Timeline';
$zmSlangSignalCheckColour    = 'Signal Check Colour';
$zmSlangSize                 = 'Size';
$zmSlangSleep                = 'Sleep';
$zmSlangSortAsc              = 'Asc';
$zmSlangSortBy               = 'Ordenar por';
$zmSlangSortDesc             = 'Desc';
$zmSlangSource               = 'Origen';
$zmSlangSourceType           = 'Tipo Origen';
$zmSlangSpeedHigh            = 'High Speed';
$zmSlangSpeedLow             = 'Low Speed';
$zmSlangSpeedMedium          = 'Medium Speed';
$zmSlangSpeed                = 'Speed';
$zmSlangSpeedTurbo           = 'Turbo Speed';
$zmSlangStart                = 'Iniciar';
$zmSlangState                = 'Estado';
$zmSlangStats                = 'Est.';
$zmSlangStatus               = 'Estado';
$zmSlangStepBack             = 'Step Back';
$zmSlangStepForward          = 'Step Forward';
$zmSlangStepLarge            = 'Large Step';
$zmSlangStepMedium           = 'Medium Step';
$zmSlangStepNone             = 'No Step';
$zmSlangStepSmall            = 'Small Step';
$zmSlangStep                 = 'Step';
$zmSlangStills               = 'Fotos';
$zmSlangStop                 = 'Desactivar';
$zmSlangStopped              = 'Apagado';
$zmSlangStreamReplayBuffer   = 'Stream Replay Image Buffer';
$zmSlangStream               = 'Stream';
$zmSlangSubmit               = 'Submit';
$zmSlangSystem               = 'Sistema';
$zmSlangTele                 = 'Tele';
$zmSlangThumbnail            = 'Thumbnail';
$zmSlangTilt                 = 'Tilt';
$zmSlangTimeDelta            = 'Hora Delta';
$zmSlangTime                 = 'Hora';
$zmSlangTimeline             = 'Timeline';
$zmSlangTimestamp            = 'Etiqueta Hora';
$zmSlangTimeStamp            = 'Etiqueta Hora';
$zmSlangTimestampLabelFormat = 'Formato Etiqueta Hora';
$zmSlangTimestampLabelX      = 'Eje X Etiqueta Hora';
$zmSlangTimestampLabelY      = 'Eje Y Etiqueta Hora';
$zmSlangToday                = 'Today';
$zmSlangTools                = 'Herra.';
$zmSlangTotalBrScore         = 'Total<br/>puntuacin';
$zmSlangTrackDelay           = 'Track Delay';
$zmSlangTrackMotion          = 'Track Motion';
$zmSlangTriggers             = 'Gatillos';
$zmSlangTurboPanSpeed        = 'Turbo Pan Speed';
$zmSlangTurboTiltSpeed       = 'Turbo Tilt Speed';
$zmSlangType                 = 'Tipo';
$zmSlangUnarchive            = 'Desarchivar';
$zmSlangUnits                = 'Unidades';
$zmSlangUnknown              = 'Desconocido';
$zmSlangUpdateAvailable      = 'Una Actualizacin a ZoneMinder esta disponible';
$zmSlangUpdateNotNecessary   = 'No se requiere Actualizacin';
$zmSlangUpdate               = 'Update';
$zmSlangUseFilterExprsPost   = '&nbsp;filtrar&nbsp;sentencias'; // This is used at the end of the phrase 'use N filter expressions'
$zmSlangUseFilterExprsPre    = 'Utilizar&nbsp;'; // This is used at the beginning of the phrase 'use N filter expressions'
$zmSlangUseFilter            = 'Usar Filtro';
$zmSlangUsername             = 'Nombre';
$zmSlangUsers                = 'Usuarios';
$zmSlangUser                 = 'Usuario';
$zmSlangValue                = 'Valor';
$zmSlangVersionIgnore        = 'Ignore esta versin';
$zmSlangVersionRemindDay     = 'Recordar en 1 da';
$zmSlangVersionRemindHour    = 'Recordar en 1 hora';
$zmSlangVersionRemindNever   = 'No avizar de nuevas versiones';
$zmSlangVersionRemindWeek    = 'Recordar en 1 semana';
$zmSlangVersion              = 'Versin';
$zmSlangVideoFormat          = 'Video Format';
$zmSlangVideoGenFailed       = 'Fallo la creacion del video!';
$zmSlangVideoGenFiles        = 'Existing Video Files';
$zmSlangVideoGenNoFiles      = 'No Video Files Found';
$zmSlangVideoGenParms        = 'Parametros Generacion Video';
$zmSlangVideoGenSucceeded    = 'Video Generation Succeeded!';
$zmSlangVideoSize            = 'Tamao Video';
$zmSlangVideo                = 'Video';
$zmSlangViewAll              = 'Ver Todo';
$zmSlangViewEvent            = 'View Event';
$zmSlangViewPaged            = 'View Paged';
$zmSlangView                 = 'Ver';
$zmSlangWake                 = 'Wake';
$zmSlangWarmupFrames         = 'Avisos Movimiento';
$zmSlangWatch                = 'Monitor';
$zmSlangWebColour            = 'Web Colour';
$zmSlangWeb                  = 'Web';
$zmSlangWeek                 = 'Semana';
$zmSlangWhiteBalance         = 'White Balance';
$zmSlangWhite                = 'White';
$zmSlangWide                 = 'Wide';
$zmSlangX10ActivationString  = 'X10 Comando Activacin';
$zmSlangX10InputAlarmString  = 'X10 Comando Entrada Alarma';
$zmSlangX10OutputAlarmString = 'X10 Output Alarm String';
$zmSlangX10                  = 'X10';
$zmSlangX                    = 'X';
$zmSlangYes                  = 'Si';
$zmSlangYouNoPerms           = 'No tiene permisos para acceder a este recurso.';
$zmSlangY                    = 'Y';
$zmSlangZoneAlarmColour      = 'Color Alarma (Red/Green/Blue)';
$zmSlangZoneArea             = 'Zone Area';
$zmSlangZoneFilterSize       = 'Filter Width/Height (pixels)';
$zmSlangZoneMinMaxAlarmArea  = 'Min/Max Alarmed Area';
$zmSlangZoneMinMaxBlobArea   = 'Min/Max Blob Area';
$zmSlangZoneMinMaxBlobs      = 'Min/Max Blobs';
$zmSlangZoneMinMaxFiltArea   = 'Min/Max Filtered Area';
$zmSlangZoneMinMaxPixelThres = 'Min/Max Pixel Threshold (0-255)';
$zmSlangZoneOverloadFrames   = 'Overload Frame Ignore Count';
$zmSlangZones                = 'Zonas';
$zmSlangZone                 = 'Zona';
$zmSlangZoomIn               = 'Zoom In';
$zmSlangZoomOut              = 'Zoom Out';
$zmSlangZoom                 = 'Zoom';

// Complex replacements with formatting and/or placements, must be passed through sprintf
$zmClangCurrentLogin         = 'Usuario actual es \'%1$s\'';
$zmClangEventCount           = '%1$s %2$s';
$zmClangLastEvents           = 'Ultimo %1$s %2$s';
$zmClangLatestRelease        = 'The latest release is v%1$s, you have v%2$s.';
$zmClangMonitorCount         = '%1$s %2$s';
$zmClangMonitorFunction      = 'Monitor %1$s Funcion';
$zmClangRunningRecentVer     = 'You are running the most recent version of Zoneminder, v%s.';

// Variable arrays expressing plurality, see the zmVlang description above
$zmVlangEvent                = array( 0=>'Eventos', 1=>'Evento', 2=>'Eventos' );
$zmVlangMonitor              = array( 0=>'Monitores', 1=>'Monitor', 2=>'Monitores' );


function zmVlang( $lang_var_array, $count )
{
	krsort( $lang_var_array );
	foreach ( $lang_var_array as $key=>$value )
	{
		if ( abs($count) >= $key )
		{
			return( $value );
		}
	}
	die( 'Error, unable to correlate variable language string' );
}

?>
